@@ -58,16 +58,14 @@
 #include <KActionCollection>
 #include <KContacts/AddresseeList>
 // #include <KContacts/Key> TODO
+#include <kmessagebox.h>
 #include <kwidgetsaddons_version.h>
 #include <KIO/Global>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/OpenUrlJob>
+#include <KIO/JobTracker>
 #include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KJobTrackerInterface>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -79,7 +77,6 @@
 #include <KStandardGuiItem>
 #include <KStandardShortcut>
 #include <KStatusNotifierItem>
-#include <KTipDialog>
 #include <KToggleAction>
 
 #include <QApplication>
@@ -97,7 +94,7 @@
 #include <QList>
 #include <QMenu>
 #include <QMetaObject>
-#include <QNetworkConfigurationManager>
+#include <QNetworkInformation>
 #include <QPainter>
 #include <QPrintDialog>
 #include <QPrinter>
@@ -108,6 +105,8 @@
 #include <QWidget>
 #include <QWidgetAction>
 
+using namespace Qt::Literals::StringLiterals;
+
 using namespace KgpgCore;
 
 KeysManager::KeysManager(QWidget *parent)
@@ -148,15 +147,8 @@ KeysManager::KeysManager(QWidget *parent)
 	// because they are used to set up the tray icon context menu
 	readOptions();
 
-	if (showTipOfDay)
-		installEventFilter(this);
-
 	QAction *action;
 
-	action = actionCollection()->addAction(QLatin1String("help_tipofday"), this, &KeysManager::slotTip);
-	action->setIcon( QIcon::fromTheme( QLatin1String( "help-hint" )) );
-	action->setText( i18n("Tip of the &Day") );
-
 	action = actionCollection()->addAction(QLatin1String("gpg_man"), this, &KeysManager::slotManpage);
 	action->setText( i18n("View GnuPG Manual") );
 	action->setIcon( QIcon::fromTheme( QLatin1String( "help-contents" )) );
@@ -417,7 +409,7 @@ KeysManager::KeysManager(QWidget *parent)
 
 	exportPublicKey->setEnabled(false);
 
-	KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig().data(), "KeyView");
+	KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig().data(), u"KeyView"_s);
 	iview->restoreLayout(cg);
 
 	connect(photoProps, &KSelectAction::indexTriggered, this, &KeysManager::slotSetPhotoSize);
@@ -462,16 +454,21 @@ KeysManager::KeysManager(QWidget *parent)
 	m_statusBarLabel.setAlignment(Qt::AlignCenter);
 	statusBar()->addPermanentWidget(&m_statusBarLabel);
 
-	cg = KConfigGroup(KSharedConfig::openConfig().data(), "MainWindow");
+	cg = KConfigGroup(KSharedConfig::openConfig().data(), u"MainWindow"_s);
 	setAutoSaveSettings(cg, true);
 	applyMainWindowSettings(cg);
 
 	connect(this, &KeysManager::fontChanged, s_kgpgEditor, &KgpgEditor::slotSetFont);
+	QNetworkInformation::loadDefaultBackend();
+	auto networkInformation = QNetworkInformation::instance();
+	if (networkInformation) {
+		Q_ASSERT(networkInformation);
+		connect(networkInformation, &QNetworkInformation::reachabilityChanged, this, [this](QNetworkInformation::Reachability reachability) {
+			toggleNetworkActions(reachability == QNetworkInformation::Reachability::Online);
+		});
 
-	QNetworkConfigurationManager *netmgr = new QNetworkConfigurationManager(this);
-	connect(netmgr, &QNetworkConfigurationManager::onlineStateChanged, this, &KeysManager::toggleNetworkActions);
-
-	toggleNetworkActions(netmgr->isOnline());
+		toggleNetworkActions(networkInformation->reachability() == QNetworkInformation::Reachability::Online);
+	}
 	importSignatureKey->setEnabled(false);
 
     stateChanged(QStringLiteral("empty_list"));
@@ -502,7 +499,7 @@ void KeysManager::slotGenerateKey()
 			m_genkey->start();
 			QApplication::setOverrideCursor(Qt::BusyCursor);
 		} else {
-			KConfigGroup config(KSharedConfig::openConfig(), "General");
+			KConfigGroup config(KSharedConfig::openConfig(), u"General"_s);
 
 			QString terminalApp(config.readPathEntry("TerminalApplication", QLatin1String( "konsole" )));
 
@@ -603,7 +600,7 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		page->kURLRequester1->setUrl(KGpgRevokeDialog::revokeUrl(genkey->getName(), email));
 
 		const QString fingerprint(genkey->getFingerprint());
-		page->TLid->setText(QLatin1String( "<b>" ) % fingerprint.rightRef(8) % QLatin1String( "</b>" ));
+		page->TLid->setText(QLatin1String( "<b>" ) % fingerprint.right(8) % QLatin1String( "</b>" ));
 		page->LEfinger->setText(fingerprint);
 		page->CBdefault->setChecked(true);
 		page->show();
@@ -711,16 +708,6 @@ void KeysManager::slotSetTrustFilter(int i)
 	iproxy->setTrustFilter(t);
 }
 
-bool KeysManager::eventFilter(QObject *, QEvent *e)
-{
-	if ((e->type() == QEvent::Show) && (showTipOfDay)) {
-		KTipDialog::showTip(this, QLatin1String("kgpg/tips"), false);
-		showTipOfDay = false;
-	}
-
-	return false;
-}
-
 void KeysManager::slotGotoDefaultKey()
 {
 	iview->selectNode(imodel->getRootNode()->findKey(KGpgSettings::defaultKey()));
@@ -1023,20 +1010,20 @@ void KeysManager::slotAddressbookSearchResult(KJob *job)
 
 	m_addIds.take(job);
 
-	ContactEditor::ContactEditorDialog *dlg;
+	Akonadi::ContactEditorDialog *dlg;
 // 	KContacts::Key key; TODO
 	if (!addresseeList.isEmpty()) {
-		dlg = new ContactEditor::ContactEditorDialog(ContactEditor::ContactEditorDialog::EditMode, this);
+		dlg = new Akonadi::ContactEditorDialog(Akonadi::ContactEditorDialog::EditMode, this);
 		dlg->setContact(searchJob->items().at(0));
 	} else {
 		KContacts::Addressee addressee;
 		addressee.setNameFromString(nd->getName());
 		addressee.setEmails(QStringList(nd->getEmail()));
-		dlg = new ContactEditor::ContactEditorDialog(ContactEditor::ContactEditorDialog::CreateMode, this);
+		dlg = new Akonadi::ContactEditorDialog(Akonadi::ContactEditorDialog::CreateMode, this);
 		dlg->editor()->setContactTemplate(addressee);
 	}
 
-	connect(dlg, &ContactEditor::ContactEditorDialog::finished, dlg, &ContactEditor::ContactEditorDialog::deleteLater);
+	connect(dlg, &Akonadi::ContactEditorDialog::finished, dlg, &Akonadi::ContactEditorDialog::deleteLater);
 	dlg->show();
 }
 
@@ -1048,11 +1035,6 @@ void KeysManager::slotManpage()
 	job->start();
 }
 
-void KeysManager::slotTip()
-{
-	KTipDialog::showTip(this, QLatin1String("kgpg/tips"), true);
-}
-
 void KeysManager::showKeyServer()
 {
 	QPointer<KeyServer> ks = new KeyServer(this, imodel);
@@ -1136,7 +1118,7 @@ void KeysManager::quitApp()
 
 void KeysManager::saveToggleOpts(void)
 {
-	KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig().data(), "KeyView");
+	KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig().data(), u"KeyView"_s);
 	iview->saveLayout(cg);
 	KGpgSettings::setPhotoProperties(photoProps->currentItem());
 	KGpgSettings::setShowTrust(sTrust->isChecked());
@@ -1158,8 +1140,6 @@ void KeysManager::readOptions()
 	if (imodel != nullptr)
 		updateStatusCounter();
 
-	showTipOfDay = KGpgSettings::showTipOfDay();
-
 	if (KGpgSettings::showSystray()) {
 		setupTrayIcon();
 	} else {
@@ -1648,10 +1628,10 @@ void KeysManager::keyproperties()
 	switch (cur->getType()) {
 	case ITYPE_SECRET:
 	case ITYPE_GSECRET:
-		if (KMessageBox::questionYesNo(this,
+		if (KMessageBox::questionTwoActions(this,
 			i18n("<p>This key is an orphaned secret key (secret key without public key.) It is currently not usable.</p>"
 					"<p>Would you like to regenerate the public key?</p>"),
-					QString(), KGuiItem(i18n("Generate")), KGuiItem(i18n("Do Not Generate"))) == KMessageBox::Yes)
+					QString(), KGuiItem(i18n("Generate")), KGuiItem(i18n("Do Not Generate"))) == KMessageBox::PrimaryAction)
 		slotregenerate();
 		return;
 	case ITYPE_PAIR:
@@ -1992,10 +1972,10 @@ void KeysManager::signatureResult(int success)
 				nd->getName(), nd->getEmail()));
 		break;
 	default:
-		if (KMessageBox::questionYesNo(this,
+		if (KMessageBox::questionTwoActions(this,
 				i18n("<qt>Signing key <b>%1</b> with key <b>%2</b> failed.<br />"
 						"Do you want to try signing the key in console mode?</qt>",
-						nd->getId(), signer)) == KMessageBox::Yes)
+						nd->getId(), signer), QString{}, KGuiItem(i18nc("@action:button", "Sign")), KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction)
 			signKeyOpenConsole(signer, nd->getId(), checklevel, localsign);
 	}
 
@@ -2058,7 +2038,7 @@ void KeysManager::slotCaffDone()
 
 void KeysManager::signKeyOpenConsole(const QString &signer, const QString &keyid, const int checking, const bool local)
 {
-	KConfigGroup config(KSharedConfig::openConfig(), "General");
+	KConfigGroup config(KSharedConfig::openConfig(), u"General"_s);
 
 	KProcess process;
 	process << config.readPathEntry("TerminalApplication", QLatin1String("konsole"))
@@ -2067,7 +2047,7 @@ void KeysManager::signKeyOpenConsole(const QString &signer, const QString &keyid
 			<< QLatin1String("--no-secmem-warning")
 			<< QLatin1String("-u") << signer
 			<< QLatin1String("--default-cert-level")
-			<< QString(checking);
+			<< QString::number(checking);
 
 	if (!local)
 		process << QLatin1String( "--sign-key" ) << keyid;
@@ -2205,7 +2185,7 @@ void KeysManager::delsignkey()
 	QString ask = i18n("<qt>Are you sure you want to delete signature<br /><b>%1</b><br />from user id <b>%2</b><br />of key: <b>%3</b>?</qt>",
 			signMail, parentMail, parentKey);
 
-	if (KMessageBox::questionYesNo(this, ask, QString(), KStandardGuiItem::del(), KStandardGuiItem::cancel()) != KMessageBox::Yes)
+	if (KMessageBox::questionTwoActions(this, ask, QString(), KStandardGuiItem::del(), KStandardGuiItem::cancel()) != KMessageBox::PrimaryAction)
 		return;
 
 	KGpgDelSign *delsig = new KGpgDelSign(this, nd->toSignNode());
@@ -2259,7 +2239,7 @@ void KeysManager::slotedit()
 		return;
 
 	KProcess *kp = new KProcess(this);
-	KConfigGroup config(KSharedConfig::openConfig(), "General");
+	KConfigGroup config(KSharedConfig::openConfig(), u"General"_s);
 	*kp << config.readPathEntry("TerminalApplication", QLatin1String("konsole"))
 			<< QLatin1String("-e")
 			<< KGpgSettings::gpgBinaryPath()
@@ -2270,7 +2250,7 @@ void KeysManager::slotedit()
 	terminalkey = nd->toKeyNode();
 	editKey->setEnabled(false);
 
-	connect(kp, QOverload<int>::of(&KProcess::finished), this, &KeysManager::slotEditDone);
+	connect(kp, &KProcess::finished, this, &KeysManager::slotEditDone);
 	kp->start();
 }
 
@@ -2312,7 +2292,7 @@ void KeysManager::removeFromGroups(KGpgKeyNode *node)
 			"<qt>The key you are deleting is a member of the following key groups. Do you want to remove it from these groups?</qt>",
 			groupNames.count());
 
-	if (KMessageBox::questionYesNoList(this, ask, groupNames, i18n("Delete key")) != KMessageBox::Yes)
+	if (KMessageBox::questionTwoActionsList(this, ask, groupNames, i18n("Delete key"), KStandardGuiItem::remove(), KStandardGuiItem::cancel()) != KMessageBox::PrimaryAction)
 		return;
 
 	bool groupDeleted = false;
@@ -2324,9 +2304,9 @@ void KeysManager::removeFromGroups(KGpgKeyNode *node)
 		bool deleteWholeGroup = (group->getChildCount() == 1) &&
 				(group->getChild(0)->toGroupMemberNode() == gref);
 		if (deleteWholeGroup)
-			deleteWholeGroup = (KMessageBox::questionYesNo(this,
+			deleteWholeGroup = (KMessageBox::questionTwoActions(this,
 					i18n("You are removing the last key from key group %1.<br/>Do you want to delete the group, too?", group->getName()),
-					i18n("Delete key")) == KMessageBox::Yes);
+					i18n("Delete key"), KStandardGuiItem::remove(), KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction);
 
 		if (!deleteWholeGroup) {
 			imodel->deleteFromGroup(group, gref);
@@ -2550,10 +2530,10 @@ void KeysManager::slotImport(const QString &text)
 	KGpgImport *imp;
 
 	if (!KGpgImport::isKey(text) && KGpgDecrypt::isEncryptedText(text)) {
-		if (KMessageBox::questionYesNo(this,
+		if (KMessageBox::questionTwoActions(this,
 				i18n("<qt>The text in the clipboard does not look like a key, but like encrypted text.<br />Do you want to decrypt it first"
 						" and then try importing it?</qt>"),
-						i18n("Import from Clipboard")) != KMessageBox::Yes)
+						i18n("Import from Clipboard"), KStandardGuiItem::ok(), KStandardGuiItem::cancel()) != KMessageBox::PrimaryAction)
 			return;
 
 		imp = new KGpgImport(this);
@@ -2643,10 +2623,12 @@ KeysManager::setupTrayIcon()
 
 	switch (KGpgSettings::leftClick()) {
 	case KGpgSettings::EnumLeftClick::Editor:
-		m_trayicon->setAssociatedWidget(s_kgpgEditor);
+		s_kgpgEditor->winId(); // create windowHandle
+		m_trayicon->setAssociatedWindow(s_kgpgEditor->windowHandle());
 		break;
 	case KGpgSettings::EnumLeftClick::KeyManager:
-		m_trayicon->setAssociatedWidget(this);
+		winId(); // create windowHandle
+		m_trayicon->setAssociatedWindow(windowHandle());
 		break;
 	}
 
@@ -2793,11 +2775,7 @@ KeysManager::slotOpenKeyUrl()
 	url.replace(QLatin1String("$$fpr$$"), idLC);
 
 	auto *job = new KIO::OpenUrlJob(QUrl(url));
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 	job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#else
-	job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#endif
 	job->start();
 }
 
