@@ -96,8 +96,6 @@ void KGpgApp::handleArguments(const QCommandLineParser &parser, const QDir &work
 	// parsing of command line args
     if (parser.isSet(QStringLiteral("k")) || (!KGpgSettings::showSystray() && parser.positionalArguments().isEmpty() && !parser.isSet(QStringLiteral("d")))) {
 		s_keyManager->show();
-		KWindowSystem::setOnDesktop(s_keyManager->winId(), KWindowSystem::currentDesktop());  //set on the current desktop
-		KWindowSystem::unminimizeWindow(s_keyManager->winId());  //de-iconify window
 		s_keyManager->raise();  // set on top
     } else if (parser.isSet(QStringLiteral("d"))) {
 		s_keyManager->slotOpenEditor();
@@ -110,7 +108,7 @@ void KGpgApp::handleArguments(const QCommandLineParser &parser, const QDir &work
 			urlList.append(QUrl::fromLocalFile(workingDirectory.absoluteFilePath(arg)));
 
 		bool directoryInside = false;
-		for (const QUrl &url : qAsConst(urlList)) {
+		for (const QUrl &url : std::as_const(urlList)) {
 			QMimeDatabase db;
 			if (db.mimeTypeForUrl(url).name() == QLatin1String( "inode/directory" )) {
 				directoryInside = true;
@@ -159,7 +157,7 @@ void KGpgApp::handleArguments(const QCommandLineParser &parser, const QDir &work
 			} else {
 				bool haskeys = false;
 				bool hastext = false;
-				for (const QUrl &url : qAsConst(urlList)) {
+				for (const QUrl &url : std::as_const(urlList)) {
 					QFile qfile(url.path());
 					if (qfile.open(QIODevice::ReadOnly)) {
 						const int probelen = 4096;
