@@ -37,8 +37,9 @@
 #include <QProcess>
 #include <QStringListModel>
 #include <QTemporaryFile>
-#include <kio/global.h>
-#include <kio/renamedialog.h>
+#include <KIO/Global>
+#include <KIO/RenameDialog>
+#include <KIO/JobTracker>
 
 KGpgExternalActions::KGpgExternalActions(KeysManager *parent, KGpgItemModel *model)
 	: QObject(parent),
@@ -394,7 +395,7 @@ void KGpgExternalActions::slotDecryptionDone(int status)
 	} else {
 		if (!m_decryptionFailed.isEmpty()) {
 			QStringList failedFiles;
-			for (const QUrl &url : qAsConst(m_decryptionFailed))
+			for (const QUrl &url : std::as_const(m_decryptionFailed))
 				failedFiles.append(url.toDisplayString());
 			KMessageBox::errorList(nullptr,
 					i18np("Decryption of this file failed:", "Decryption of these files failed:",
@@ -420,7 +421,7 @@ void KGpgExternalActions::readOptions()
 	if (KGpgSettings::firstRun()) {
 		firstRun();
 	} else if (KGpgSettings::gpgConfigPath().isEmpty()) {
-                if (KMessageBox::Yes == KMessageBox::questionYesNo(nullptr,
+                if (KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(nullptr,
 				i18n("<qt>You have not set a path to your GnuPG config file.<br />This may cause some surprising results in KGpg's execution."
 				"<br />Would you like to start KGpg's assistant to fix this problem?</qt>"),
 				QString(), KGuiItem(i18n("Start Assistant")), KGuiItem(i18n("Do Not Start"))))
